# -*- coding: utf-8 -*-

# Informations utilisée par l'installeur sous Windows.
# titre : description sommaire du module
# description : description détaillée
# defaut : par défaut, le module est-il installé ou non ?

description = {
"titre":                    "Exercices - Tableaux de signes",
"description":              "Série de tableaux de signes à remplir.",
"groupe":                   "Modules",
"defaut":  True,
}
